@@ -15,3 +15,6 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 from pyextremes.eva import EVA
+from pyextremes.extremes import get_extremes, get_return_periods
+
+__version__ = '0.2.0'
